Risk Distributions
======================

.. image:: https://badge.fury.io/py/risk_distributions.svg
    :target: https://badge.fury.io/py/risk-distributions

.. image:: https://github.com/ihmeuw/risk_distributions/actions/workflows/build.yml/badge.svg?branch=main
    :target: https://github.com/ihmeuw/risk_distributions
    :alt: Latest Version

.. image:: https://readthedocs.org/projects/risk-distributions/badge/?version=latest
    :target: https://risk-distributions.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

This library contains various probability distributions, compatible for use with the ``Vivarium`` framework

You can install ``risk_distributions`` from PyPI with pip:

  ``> pip install risk_distributions``

or build it from source with

  ``> git clone https://github.com/ihmeuw/risk_distributions.git``

  ``> cd risk_distributions``

  ``> python setup.py install``


`Check out the docs! <https://risk-distributions.readthedocs.io/en/latest/>`_
-----------------------------------------------------------------------------
